@@ -1,4 +1,4 @@
-# SpectroscPy 0.3.0
+# SpectroscPy 0.3.1
 # SpectroscPy is a script package developed by and containing contributions from
 
     # Karen Oda Hjorth Minde Dundas
@@ -439,15 +439,15 @@ def get_anharm_fundamental_transition_moment(property_gradient, property_hessian
                         if (abs(cubic_ff[i][j][k]*cubic_ff[l][l][k]) > prod2):
                             prod2 = abs(cubic_ff[i][j][k]*cubic_ff[l][l][k])
 
-                if is_11_resonance(vi - vj, kijkk):
+                if is_11_resonance(vi - vj, kijkk, 'quartic'):
                     print('1-1 resonance: ', i, j)
                     DD_resonances.append(sorted([i, j]))
                 else:
-                    if is_11_resonance(vi - vj, prod1):
+                    if is_11_resonance(vi - vj, prod1, 'cubic'):
                         print('1-1 resonance: ', i, j)
                         DD_resonances.append(sorted([i, j]))
                     else:
-                        if is_11_resonance(vi - vj, prod2):
+                        if is_11_resonance(vi - vj, prod2, 'cubic'):
                             print('1-1 resonance: ', i, j)
                             DD_resonances.append(sorted([i, j]))
 
@@ -477,7 +477,7 @@ def get_anharm_fundamental_transition_moment(property_gradient, property_hessian
 
                     if (i != j):
                         # 1-1 resonance
-                        if (not is_11_resonance(vi - vj, kijkk) or not do_DD_check):
+                        if (not is_11_resonance(vi - vj, kijkk, 'quartic') or not do_DD_check):
                             if not (do_forced_DD_removal and (sorted([i, j]) in DD_resonances)):
                                 tmp1 = tmp1 - 1/(vi - vj)
 
@@ -509,7 +509,8 @@ def get_anharm_fundamental_transition_moment(property_gradient, property_hessian
                             tmp1 = tmp1 + 1/((vi + vk + vl)*(vj + vk + vl))
                             tmp1 = tmp1 + 1/((vi + vj)*(vi + vk + vl))
 
-                            if (not is_11_resonance(vi - vj, kikl*kjkl) or not do_DD_check):
+                            if (not is_11_resonance(vi - vj, kikl*kjkl, 'cubic') or not \
+                                do_DD_check):
                                 if not (do_forced_DD_removal and (sorted([i, j]) in DD_resonances)):
                                     tmp1 = tmp1 - 1/((vi - vj)*(vj + vk + vl))
 
@@ -517,9 +518,10 @@ def get_anharm_fundamental_transition_moment(property_gradient, property_hessian
                                 not do_fermi_check):
                                 tmp1 = tmp1 - 1/((vi - vk - vl)*(vj + vk + vl))
 
-                                if (not is_11_resonance(vi - vj, kikl*kjkl) or \
+                                if (not is_11_resonance(vi - vj, kikl*kjkl, 'cubic') or \
                                     not do_DD_check):
-                                    if not (do_forced_DD_removal and (sorted([i, j]) in DD_resonances)):
+                                    if not (do_forced_DD_removal and (sorted([i, j]) in \
+                                            DD_resonances)):
                                         tmp1 = tmp1 + 1/((vi - vj)*(vi - vk - vl))
 
                             transition_moment[i][a] = transition_moment[i][a] + \
@@ -555,11 +557,14 @@ def get_anharm_fundamental_transition_moment(property_gradient, property_hessian
                             if (not is_fermi_resonance(vj + vk - vi, cubic_ff[i][j][k], k == j) or \
                                 not do_fermi_check):
                                 tmp1 = tmp1 - 1/(vk*(vi - vj - vk))
-                                if (not is_11_resonance(vi - vj, kikl*kjkl) or not do_DD_check):
-                                    if not (do_forced_DD_removal and (sorted([i, j]) in DD_resonances)):
+                                if (not is_11_resonance(vi - vj, kikl*kjkl, 'cubic') or not \
+                                    do_DD_check):
+                                    if not (do_forced_DD_removal and (sorted([i, j]) in \
+                                            DD_resonances)):
                                         tmp1 = tmp1 + 1/((vi - vj)*(vi - vj - vk))
 
-                            if (not is_11_resonance(vi - vj, kikl*kjkl) or not do_DD_check):
+                            if (not is_11_resonance(vi - vj, kikl*kjkl, 'cubic') or not \
+                                do_DD_check):
                                 if not (do_forced_DD_removal and (sorted([i, j]) in DD_resonances)):
                                     tmp1 = tmp1 - 2/((vi - vj)*(vi + vj + vk))
                                     tmp1 = tmp1 - 3/(vk*(vi - vj))
@@ -587,15 +592,18 @@ def get_anharm_fundamental_transition_moment(property_gradient, property_hessian
                             tmp1 = tmp1 + 1/(vk*(vi + vj))
                             tmp1 = tmp1 + 1/(vk*(vi + vj + vk))
 
-                            if (not is_11_resonance(vi - vj, kijk*kllk) or not do_DD_check):
+                            if (not is_11_resonance(vi - vj, kijk*kllk, 'cubic') or not \
+                                do_DD_check):
                                 if not (do_forced_DD_removal and (sorted([i, j]) in DD_resonances)):
                                     tmp1 = tmp1 - 1/(vk*(vi - vj))
 
                             if (not is_fermi_resonance(vj + vk - vi, cubic_ff[i][j][k], k == j) or \
                                 not do_fermi_check):
                                 tmp1 = tmp1 - 1/(vk*(vi - vj - vk))
-                                if (not is_11_resonance(vi - vj, kijk*kllk) or not do_DD_check):
-                                    if not (do_forced_DD_removal and (sorted([i, j]) in DD_resonances)):
+                                if (not is_11_resonance(vi - vj, kijk*kllk, 'cubic') or not \
+                                    do_DD_check):
+                                    if not (do_forced_DD_removal and (sorted([i, j]) in \
+                                            DD_resonances)):
                                         tmp1 = tmp1 + 1/((vi - vj)*(vi - vj - vk))
 
                             transition_moment[i][a] = transition_moment[i][a] + \
@@ -611,7 +619,8 @@ def get_anharm_fundamental_transition_moment(property_gradient, property_hessian
                             # 1-1 resonance
                             tmp1 = 1/((2*vi + vj)*(vi + vj))
                             tmp1 = tmp1 + 1/(vi*(2*vi + vj))
-                            if (not is_11_resonance(vi - vj, kijk*kllk) or not do_DD_check):
+                            if (not is_11_resonance(vi - vj, kijk*kllk, 'cubic') or not \
+                                do_DD_check):
                                 if not (do_forced_DD_removal and (sorted([i, j]) in DD_resonances)):
                                     tmp1 = tmp1 - 1/(vi*(vi - vj))
 
@@ -621,14 +630,17 @@ def get_anharm_fundamental_transition_moment(property_gradient, property_hessian
                                 tmp1 = tmp1 + 1/(3*vi*(vi + vj))
                                 tmp1 = tmp1 + 1/(3*vi*(2*vi + vj))
 
-                                if (not is_11_resonance(vi - vj, kijk*kllk) or not do_DD_check):
-                                    if not (do_forced_DD_removal and (sorted([i, j]) in DD_resonances)):
+                                if (not is_11_resonance(vi - vj, kijk*kllk, 'cubic') or not \
+                                    do_DD_check):
+                                    if not (do_forced_DD_removal and (sorted([i, j]) in \
+                                            DD_resonances)):
                                         tmp1 = tmp1 - 1/((vi - vj)*(2*vi + vj))
 
                             tmp1 = tmp1 + 1/(vi*(vi + vj))
                             tmp1 = tmp1 + 1/(vi*vj)
 
-                            if (not is_11_resonance(vi - vj, kijk*kllk) or not do_DD_check):
+                            if (not is_11_resonance(vi - vj, kijk*kllk, 'cubic') or not \
+                                do_DD_check):
                                 if not (do_forced_DD_removal and (sorted([i, j]) in DD_resonances)):
                                     tmp1 = tmp1 - 1/(vj*(vi - vj))
 
