@@ -1,4 +1,4 @@
-# SpectroscPy 0.3.0
+# SpectroscPy 0.3.1
 # SpectroscPy is a script package developed by and containing contributions from
 
     # Karen Oda Hjorth Minde Dundas
@@ -615,8 +615,8 @@ def test_get_anharm_corrected_transition_moment():
     # DVPT2 with 1-1 checks
     ref_ftm = [[ 1.32853011e-30,  5.20012975e-32, -3.44446578e-46],
                [-1.53619477e-36, -2.87420688e-36,  2.44445677e-45],
-               [ 1.14070630e-41, -2.91485021e-40, -6.00866116e-31],
-               [ 2.35025971e-32, -6.00405062e-31,  3.51997146e-40]]
+               [ 2.62827327e-39, -6.71427369e-38, -6.00866116e-31],
+               [ 2.35025971e-32, -6.00405062e-31,  6.72545877e-38]]
 
     transition_moments = get_anharm_corrected_transition_moment(CO2_dipole_gradient, \
                                                                 CO2_dipole_hessian, \
@@ -669,6 +669,11 @@ def test_get_anharm_corrected_transition_moment():
            np.multiply(transition_moments.combotones, 1.0e40))
     
     # GVPT2 frequencies, DVPT2 intensities, w/ 1-1 checks with forced removal of all i,j
+    ref_ftm = [[ 1.32853011e-30,  5.20012975e-32, -3.44446578e-46],
+               [-1.53619477e-36, -2.87420688e-36,  2.44445677e-45],
+               [ 1.14070630e-41, -2.91485021e-40, -6.00866116e-31],
+               [ 2.35025971e-32, -6.00405062e-31,  3.51997146e-40]]
+
     transition_moments = \
         get_anharm_corrected_transition_moment(CO2_dipole_gradient, CO2_dipole_hessian, \
                                                CO2_dipole_cubic, CO2_cubic_ff, CO2_quartic_ff, \
@@ -683,7 +688,6 @@ def test_get_anharm_corrected_transition_moment():
            np.multiply(transition_moments.overtones, 1.0e40))
     assert np.allclose(np.multiply(ref_combotone_tm, 1.0e40), \
            np.multiply(transition_moments.combotones, 1.0e40))
-    
 
 
 def test_get_overtone_transition_moment():
@@ -885,12 +889,13 @@ def test_get_anharm_fundamental_transition_moment():
     # DVPT2 with 1-1 checks
     ref_ftm = [[ 1.32853011e-30,  5.20012975e-32, -3.44446578e-46],
                [-1.53619477e-36, -2.87420688e-36,  2.44445677e-45],
-               [ 1.14070630e-41, -2.91485021e-40, -6.00866116e-31],
-               [ 2.35025971e-32, -6.00405062e-31,  3.51997146e-40]]
+               [ 2.62827327e-39, -6.71427369e-38, -6.00866116e-31],
+               [ 2.35025971e-32, -6.00405062e-31,  6.72545877e-38]]
 
     ftm = get_anharm_fundamental_transition_moment(CO2_dipole_gradient, CO2_dipole_hessian, \
-                                                   CO2_dipole_cubic, CO2_cubic_ff, CO2_quartic_ff, \
-                                                   CO2_harmonic_energies, 'No coriolis', 0, \
+                                                   CO2_dipole_cubic, CO2_cubic_ff, \
+                                                   CO2_quartic_ff, CO2_harmonic_energies, \
+                                                   'No coriolis', 0, \
                                                    'Anharmonic: DVPT2, w/ 1-1 checks')
 
     assert np.allclose(np.multiply(ref_ftm, 1.0e40), np.multiply(ftm, 1.0e40))
@@ -911,24 +916,30 @@ def test_get_anharm_fundamental_transition_moment():
     # GVPT2 frequencies, DVPT2 intensities, w/ 1-1 checks
     ref_ftm = [[ 1.32853011e-30,  5.20012975e-32, -3.44446578e-46],
                [-1.53619477e-36, -2.87420688e-36,  2.44445677e-45],
-               [ 1.14070630e-41, -2.91485021e-40, -6.00866116e-31],
-               [ 2.35025971e-32, -6.00405062e-31,  3.51997146e-40]]
+               [ 2.62827327e-39, -6.71427369e-38, -6.00866116e-31],
+               [ 2.35025971e-32, -6.00405062e-31,  6.72545877e-38]]
 
     ftm = get_anharm_fundamental_transition_moment(CO2_dipole_gradient, CO2_dipole_hessian, \
-                                                   CO2_dipole_cubic, CO2_cubic_ff, CO2_quartic_ff, \
-                                                   CO2_harmonic_energies, 'No coriolis', 0, \
-                                                   'Anharmonic: Freq GVPT2, Int DVPT2, w/ 1-1 checks')
+                                                   CO2_dipole_cubic, CO2_cubic_ff, \
+                                                   CO2_quartic_ff, CO2_harmonic_energies, \
+                                                   'No coriolis', 0, \
+                                                'Anharmonic: Freq GVPT2, Int DVPT2, w/ 1-1 checks')
 
     assert np.allclose(np.multiply(ref_ftm, 1.0e40), np.multiply(ftm, 1.0e40))
 
     # GVPT2 frequencies, DVPT2 intensities, w/ 1-1 checks with forced removal
+    ref_ftm = [[ 1.32853011e-30,  5.20012975e-32, -3.44446578e-46],
+               [-1.53619477e-36, -2.87420688e-36,  2.44445677e-45],
+               [ 1.14070630e-41, -2.91485021e-40, -6.00866116e-31],
+               [ 2.35025971e-32, -6.00405062e-31,  3.51997146e-40]]
+
     ftm = get_anharm_fundamental_transition_moment(CO2_dipole_gradient, CO2_dipole_hessian, \
-                                                   CO2_dipole_cubic, CO2_cubic_ff, CO2_quartic_ff, \
-                                                   CO2_harmonic_energies, 'No coriolis', 0, \
-                                                   'Anharmonic: Freq GVPT2, Int DVPT2, w/ 1-1 checks and forced removal')
+                                                   CO2_dipole_cubic, CO2_cubic_ff, \
+                                                   CO2_quartic_ff, CO2_harmonic_energies, \
+                                                   'No coriolis', 0, \
+                            'Anharmonic: Freq GVPT2, Int DVPT2, w/ 1-1 checks and forced removal')
 
     assert np.allclose(np.multiply(ref_ftm, 1.0e40), np.multiply(ftm, 1.0e40))
-    
 
 
 def test_anharm_corrected_vibrational_energies():
