@@ -1,4 +1,4 @@
-# SpectroscPy 0.3.0
+# SpectroscPy 0.3.1
 # SpectroscPy is a script package developed by and containing contributions from
 
     # Karen Oda Hjorth Minde Dundas
@@ -58,8 +58,28 @@ def test_add_fermi_resonance():
 
 def test_is_11_resonance():
 
-    assert is_11_resonance(5.0e-21, 1.0e-22) == 0
-    assert is_11_resonance(5.0e-21, 3.0e-22) == 0
-    assert is_11_resonance(1.0e-21, 1.0e-65) == 0
-    assert is_11_resonance(1.0e-21, 2.0e-65) == 1
-    assert is_11_resonance(1.0e-22, 3.0e-22) == 1
+    # Too large delta, too small K
+    assert is_11_resonance(5.0e-21, 1.0e-22, 'quartic') == 0
+    # Too large delta, but large enough K
+    assert is_11_resonance(5.0e-21, 3.0e-22, 'quartic') == 0
+    # Small enough delta, but too small K, in both K/v^2 and K
+    assert is_11_resonance(1.0e-21, 1.0e-22, 'quartic') == 0
+    # Very small delta, but too small K/v^2
+    assert is_11_resonance(1.0e-23, 1.0e-24, 'quartic') == 0
+    # Small enough delta, large enough enough K
+    assert is_11_resonance(1.0e-21, 3.0e-22, 'quartic') == 1
+    # Very small delta, too small K, but K/v^2 large enough
+    assert is_11_resonance(1.0e-23, 1.0e-22, 'quartic') == 1
+
+    # Too large delta, too small K
+    assert is_11_resonance(5.0e-21, 1.0e-45, 'cubic') == 0
+    # Too large delta, but large enough K
+    assert is_11_resonance(5.0e-21, 5.0e-45, 'cubic') == 0
+    # Small enough delta, but too small K, in both K/v^2 and K
+    assert is_11_resonance(1.0e-21, 1.0e-45, 'cubic') == 0
+    # Very small delta, but too small K/v^2
+    assert is_11_resonance(1.0e-23, 7.0e-47, 'cubic') == 0
+    # Small enough delta, large enough enough K
+    assert is_11_resonance(1.0e-21, 5.0e-45, 'cubic') == 1
+    # Very small delta, too small K, but K/v^2 large enough
+    assert is_11_resonance(1.0e-23, 2.0e-46, 'cubic') == 1
